import type { Placement } from '@floating-ui/dom';
/**
 * 创建 DOM 元素
 * @param tagName 标签名
 * @param props 属性对象
 * @param children 子元素数组
 * @returns HTMLElement
 */
export declare function createElement<K extends keyof HTMLElementTagNameMap>(tagName: K, props?: Record<string, any>, children?: (string | HTMLElement)[]): HTMLElementTagNameMap[K];
/**
 * 获取定位的静态边
 * @param placement 定位位置
 * @returns 静态边
 */
export declare function getStaticSide(placement: Placement): string;
/**
 * 判断元素是否在可视区域内
 * @param element 要检查的元素
 * @returns 是否完全可见
 */
export declare function isElementInViewport(element: HTMLElement): boolean;
/**
 * 获取当前页面最高的 z-index 值
 * @description 只检查可能具有较高 z-index 的元素，如 fixed/absolute 定位的元素
 * @returns {number} 最高的 z-index 值加 1
 */
export declare function getHighestZIndex(): number;
